@@ -75,10 +75,6 @@
 
 #include <config.h>
 
-#ifndef TQT_CLEAN_NAMESPACE
-#define TQT_CLEAN_NAMESPACE
-#endif
-
 #include "tqdatetime.h"
 #include "mngformattype.h"
 
